Range-v3: range/v3/algorithm/permutation.hpp File Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Classes | Typedefs | Variables
permutation.hpp File Reference

## Classes
struct | ranges::v3::is_permutation_fn
struct | ranges::v3::next_permutation_fn
struct | ranges::v3::prev_permutation_fn

## Typedefs
template<typename I1 , typename I2 , typename C = equal_to, typename P1 = ident, typename P2 = ident>
using | ranges::v3::IsPermutationable = meta::strict_and< ForwardIterator< I1 >, ForwardIterator< I2 >, Comparable< I1, I2, C, P1, P2 > >

## Variables
constexpr with_braced_init_args< is_permutation_fn > | ranges::v3::is_permutation {}
constexpr with_braced_init_args< next_permutation_fn > | ranges::v3::next_permutation {}
constexpr with_braced_init_args< prev_permutation_fn > | ranges::v3::prev_permutation {}